#ifndef __PCI9016_H__
#define __PCI9016_H__

#define PCI9016_API __declspec(dllimport)

typedef enum _PN_NUMBER_{
    PN_OutputMode = 1000,       //pulse output mode, 0 for PUL/DIR, 1 for CW/CCW

    PN_InvertOutputDirection = 1004, //invert output direction
    PN_InputMode,               //pulse input mode, 0 for PUL/DIR, 1 for CW/CCW
    PN_InvertInputDirection,    //invert input counter direction
    PN_PosLimitSwitchType,      //hardware limit switch type, 0 for normal open, 1 for normal close
    PN_PosLimitSwitchEnable,    //enable positive hard limit input, non-zero for enable, zero for disable
    PN_NegLimitSwitchType,      //reserved
    PN_NegLimitSwitchEnable,    //enable negative hard limit input, non-zero for enable, zero for disable
    PN_HomeSwitchType,          //home switch type, zero for normal open, non-zero for normal close
    PN_HomeSwitchEnable,        //reserved
    PN_IndexActiveLevel,        //index active level, zero for low level, non-zero for high level
    PN_AmpFaultType,            //reserved
    PN_AmpFaultEnable,          //reserved
    PN_AbortSwitchType,         //abort input type(supported from FPGA version of 0x0108)
    PN_AbortSwitchEnable        //enable abort input(supported from FPGA version of 0x0108)
}PN_NUMBER;

//  Data structures (set packing to 4-byte).
#pragma pack(push,4)

typedef struct _MOT_AXIS_STAT{
    double          cmdPos;            //current command position
    double          cmdVel;            //current command velocity
    double          cmdAcc;            //reserved
    double          actPos;            //current feedback position
    double          actVel;            //reserved
    double          actAcc;            //reserved
    double          reserved1;         //reserved
    double          reserved2;         //reserved
    int             homeSwitch;         //non-zero means home switch is tripped
    int             negHardLimit;       //non-zero means positive hard limit tripped
    int             posHardLimit;       //non-zero means negative hard limit tripped
    int             fault;              //reserved
    int             abort;              //reserved
    int             minSoftLimit;       //reserved
    int             maxSoftLimit;       //reserved
    int             inpos;              //non-zero means axis stops
    int             enabled;            //reserved
    int             homing;             //reserved
    int             homed;              //reserved
    int             error;              //non-zero means error(exception encounterd in last move)
}MOT_AXIS_STAT;

typedef struct _MOT_CMP_STAT{
    int             queFull;            //nonzero means reference queue full
    int             queEmpty;           //nonzero means reference queue empty
    int             queItem;            //queued items
    int             curRef;             //current reference
    int             matchCount;         //match count
    int             reserved[3];        //reserved
}MOT_CMP_STAT;

//  Restore default packing
#pragma pack(pop)

#ifdef __cplusplus
extern "C" {
#endif
//open/close
PCI9016_API int WINAPI p9016_initial(int* pCard_count, int* pBoard_id);
PCI9016_API int WINAPI p9016_close();

//deprecated interface-->
//pulse input/output configuration
PCI9016_API int WINAPI p9016_set_pls_outmode(int axis, int pls_outmode);
PCI9016_API int WINAPI p9016_set_pls_iptmode(int axis, int pls_iptmode);

//parameter setting
PCI9016_API int WINAPI p9016_set_t_profile(int axis, double start_vel, double max_vel, double acc, double dec);

//single axis driving functions
//dist_mode:  0  incremental coordinate; 1 - absolute coordinate
//vel_mode:   0  low speed mode without acc/dec;
//            1 high speed mode without acc/dec;
//            2 high speed mode with acc/dec
PCI9016_API int WINAPI p9016_pmove(int axis, int dist, int dist_mode, int vel_mode);
PCI9016_API int WINAPI p9016_vmove(int axis, int plus_dir, int vel_mode);
PCI9016_API int WINAPI p9016_stop(int axis, int EmgStop);

//home return
//mode:     0   - low speed, ORG only;
//          1   - high speed, ORG only;
//          2   - low speed,  ORG + EZ;
//          3   - high speed, ORG + EZ
PCI9016_API int WINAPI p9016_home_config(int axis, int mode, int org_level, int ez_level);
PCI9016_API int WINAPI p9016_home_move(int axis, int PlusDir);

//position counter control
PCI9016_API int WINAPI p9016_set_pos(int axis, int cntr_no, int pos);
PCI9016_API int WINAPI p9016_get_pos(int axis, int cntr_no, int* pPos);

//I/O control
PCI9016_API int WINAPI p9016_set_do(int card_no, unsigned int data);
PCI9016_API int WINAPI p9016_set_do_bit(int card_no, unsigned int bit_no, unsigned int data);
PCI9016_API int WINAPI p9016_get_do(int card_no, unsigned int* pData);
PCI9016_API int WINAPI p9016_get_di(int card_no, unsigned int* pData);
PCI9016_API int WINAPI p9016_get_di_bit(int card_no, unsigned int bit_no, unsigned int* pData);

//mechanical switch status
PCI9016_API int WINAPI p9016_get_io_status(int axis, unsigned int* pStatus);

//motion status
PCI9016_API int WINAPI p9016_get_motion_status(int axis, unsigned int* pStatus);
PCI9016_API int WINAPI p9016_get_current_speed(int axis, double* pSpeed);

//version
PCI9016_API int WINAPI p9016_get_version(int card_no, unsigned int* pApi_ver, unsigned int* pDriver_ver, unsigned int *pLogic_ver);

PCI9016_API int WINAPI p9016_set_el_level(int axis, int active_level);
PCI9016_API int WINAPI p9016_set_error_stop_mode(int axis, int stop_mode);
//<--deprecated interface

PCI9016_API int WINAPI p9016_axis_cont_move(int axis, double vel);
PCI9016_API int WINAPI p9016_axis_incr_move(int axis, int incr);
PCI9016_API int WINAPI p9016_axis_abs_move(int axis, int pos);
PCI9016_API int WINAPI p9016_axis_home(int axis, double vel, int use_index);
PCI9016_API int WINAPI p9016_axis_abort(int axis);

PCI9016_API int WINAPI p9016_axis_set_cmd_pos(int axis, int pos);
PCI9016_API int WINAPI p9016_axis_set_act_pos(int axis, int pos);
PCI9016_API int WINAPI p9016_axis_set_profile(int axis, double min_vel, double max_vel, double accel, double decel, double jerk);
PCI9016_API int WINAPI p9016_axis_set_parameter(int axis, int param_num, int value);
PCI9016_API int WINAPI p9016_axis_set_real_parameter(int axis, int param_num, double value);

PCI9016_API int WINAPI p9016_axis_get_status(int axis, MOT_AXIS_STAT * pStat);
PCI9016_API int WINAPI p9016_axis_get_status_ex(int axis, int* buff, int cnt);

PCI9016_API int WINAPI p9016_cmp_enable(int card_no, int index, int enable, int active_level, int ref_source, int length);
PCI9016_API int WINAPI p9016_cmp_set_ref(int card_no, int index, int pos);
PCI9016_API int WINAPI p9016_cmp_get_status(int card_no, int index, MOT_CMP_STAT* pStatus);

PCI9016_API int WINAPI p9016_motion_set_dout(int card_no, int index, int value);
PCI9016_API int WINAPI p9016_motion_set_dout_ex(int card_no, unsigned int value);
PCI9016_API int WINAPI p9016_motion_get_dout(int card_no, int index, int* pValue);
PCI9016_API int WINAPI p9016_motion_get_dout_ex(int card_no, unsigned int* pValue);
PCI9016_API int WINAPI p9016_motion_get_din(int card_no, int index, int* value);
PCI9016_API int WINAPI p9016_motion_get_din_ex(int card_no, unsigned int* value);

PCI9016_API int WINAPI p9016_motion_get_info(int card_no, unsigned int* buff, int count);
#ifdef __cplusplus
}
#endif
#endif
