﻿'
'   Header File for PCI-9016
'
'   History:
'   2014/7/1   created
'   2019/6/29  update for API v1.06
'
Option Strict Off
Option Explicit On
Imports System.Runtime.InteropServices
Module Pci9016
#Region "Global constants"
    Public Enum PN_NUMBER
        PN_OutputMode = 1000                 'pulse output mode, 0 for PUL/DIR, 1 for CW/CCW

        PN_InvertOutputDirection = 1004     'invert direction output, non-zero for enable, zero for disable
        PN_InputMode                        'pulse input mode, 0 for PUL/DIR, 1 for CW/CCW
        PN_InvertInputDirection             'invert feedback counter counting direction, non-zero for enable, zero for disable
        PN_PosLimitSwitchType               'hardware limit switch type, zero for normal open, non-zero for normal close
        PN_PosLimitSwitchEnable             'enable positive hard limit input, non-zero for enable, zero for disable
        PN_NegLimitSwitchType               'reserved
        PN_NegLimitSwitchEnable             'enable negative hard limit input, non-zero for enable, zero for disable
        PN_HomeSwitchType                   'home switch type, zero for normal open, non-zero for normal close
        PN_HomeSwitchEnable                 'reserved
        PN_IndexActiveLevel                 'index active level, zero for low level, non-zero for high level
    End Enum
#End Region

#Region "Structure Definitions"
    <StructLayoutAttribute(LayoutKind.Sequential, Pack:=4)> _
    Public Structure MOT_AXIS_STAT
        Public cmdPos As Double         'current command position
        Public cmdVel As Double         'current command velocity
        Public cmdAcc As Double         'reserved
        Public actPos As Double         'current feedback position
        Public actVel As Double         'reserved
        Public actAcc As Double         'reserved
        Public reserved1 As Double      'reserved
        Public reserved2 As Double      'reserved
        Public homeSwitch As Integer    'non-zero means home switch is tripped
        Public negHardLimit As Integer  'non-zero means positive hard limit tripped
        Public posHardLimit As Integer  'non-zero means negative hard limit tripped
        Public fault As Integer         'reserved
        Public abort As Integer         'non-zero means emg. input is active
        Public minSoftLimit As Integer  'reserved
        Public maxSoftLimit As Integer  'reserved
        Public inpos As Integer         'non-zero means axis stops
        Public enabled As Integer       'reserved
        Public homing As Integer        'reserved
        Public homed As Integer         'reserved
        Public err As Integer           'non-zero means error(exception encounterd in last move)
    End Structure

    <StructLayoutAttribute(LayoutKind.Sequential, Pack:=4)> _
    Public Structure MOT_CMP_STAT
        Public queFull As Integer       'nonzero means reference queue is full
        Public queEmpty As Integer      'nonzero means reference queue is empty
        Public queItem As Integer       'queued items
        Public curRef As Integer        'current reference
        Public matchCount As Integer    'match count
        Public reserved1 As Integer     'reserved
        Public reserved2 As Integer     'reserved
        Public reserved3 As Integer     'reserved
    End Structure
#End Region

#Region "Function Prototype"
    Declare Function p9016_initial Lib "Pci9016.dll" (ByRef pCard_count As Integer, ByVal Board_id As Integer()) As Integer
    Declare Function p9016_close Lib "Pci9016.dll" () As Integer

    'Deprecated API -->
    '遗留接口(legacy API)，新应用不建议使用
    Declare Function p9016_set_pls_outmode Lib "Pci9016.dll" (ByVal axis As Integer, ByVal pls_outmode As Integer) As Integer
    Declare Function p9016_set_pls_iptmode Lib "Pci9016.dll" (ByVal axis As Integer, ByVal pls_iptmode As Integer) As Integer

    Declare Function p9016_set_t_profile Lib "Pci9016.dll" (ByVal axis As Integer, ByVal start_vel As Double, ByVal max_vel As Double, ByVal acc As Double, ByVal dec As Double) As Integer

    Declare Function p9016_pmove Lib "Pci9016.dll" (ByVal axis As Integer, ByVal dist As Integer, ByVal dist_mode As Integer, ByVal vel_mode As Integer) As Integer
    Declare Function p9016_vmove Lib "Pci9016.dll" (ByVal axis As Integer, ByVal plus_dir As Integer, ByVal vel_mode As Integer) As Integer
    Declare Function p9016_stop Lib "Pci9016.dll" (ByVal axis As Integer, ByVal EmgStop As Integer) As Integer

    Declare Function p9016_home_config Lib "Pci9016.dll" (ByVal axis As Integer, ByVal mode As Integer, ByVal org_level As Integer, ByVal ez_level As Integer) As Integer
    Declare Function p9016_home_move Lib "Pci9016.dll" (ByVal axis As Integer, ByVal plus_dir As Integer) As Integer

    Declare Function p9016_get_pos Lib "Pci9016.dll" (ByVal axis As Integer, ByVal cntr_no As Integer, ByRef Pos As Integer) As Integer
    Declare Function p9016_set_pos Lib "Pci9016.dll" (ByVal axis As Integer, ByVal cntr_no As Integer, ByVal pos As Integer) As Integer

    Declare Function p9016_set_do Lib "Pci9016.dll" (ByVal card_no As Integer, ByVal data As UInteger) As Integer
    Declare Function p9016_set_do_bit Lib "Pci9016.dll" (ByVal card_no As Integer, ByVal bit_no As UInteger, ByVal data As UInteger) As Integer
    Declare Function p9016_get_do Lib "Pci9016.dll" (ByVal card_no As Integer, ByRef data As UInteger) As Integer
    Declare Function p9016_get_di Lib "Pci9016.dll" (ByVal card_no As Integer, ByRef data As UInteger) As Integer
    Declare Function p9016_get_di_bit Lib "Pci9016.dll" (ByVal card_no As Integer, ByVal bit_no As UInteger, ByRef data As UInteger) As Integer


    Declare Function p9016_get_io_status Lib "Pci9016.dll" (ByVal axis As Integer, ByRef status As UInteger) As Integer
    Declare Function p9016_get_motion_status Lib "Pci9016.dll" (ByVal axis As Integer, ByRef status As UInteger) As Integer
    Declare Function p9016_get_current_speed Lib "Pci9016.dll" (ByVal axis As Integer, ByRef pspeed As Double) As Integer

    Declare Function p9016_get_version Lib "Pci9016.dll" (ByVal card_no As Integer, ByRef Api_ver As UInteger, ByRef Driver_ver As UInteger, ByRef Logic_ver As UInteger) As Integer
    Declare Function p9016_set_el_level Lib "Pci9016.dll" (ByVal axis As Integer, ByVal active_level As Integer) As Integer
    Declare Function p9016_set_error_stop_mode Lib "Pci9016.dll" (ByVal axis As Integer, ByVal stop_mode As Integer) As Integer
    Declare Function p9016_set_alarm Lib "Pci9016.dll" (ByVal axis As Integer, ByVal enable As Integer, ByVal type As Integer) As Integer
    '<--Deprecated API
    '

    Declare Function p9016_axis_cont_move Lib "Pci9016.dll" (ByVal axis As Integer, ByVal vel As Double) As Integer
    Declare Function p9016_axis_incr_move Lib "Pci9016.dll" (ByVal axis As Integer, ByVal incr As Integer) As Integer
    Declare Function p9016_axis_abs_move Lib "Pci9016.dll" (ByVal axis As Integer, ByVal pos As Integer) As Integer
    Declare Function p9016_axis_home Lib "Pci9016.dll" (ByVal axis As Integer, ByVal vel As Double, ByVal use_index As Integer) As Integer
    Declare Function p9016_axis_abort Lib "Pci9016.dll" (ByVal axis As Integer) As Integer

    Declare Function p9016_axis_set_cmd_pos Lib "Pci9016.dll" (ByVal axis As Integer, ByVal pos As Integer) As Integer
    Declare Function p9016_axis_set_act_pos Lib "Pci9016.dll" (ByVal axis As Integer, ByVal pos As Integer) As Integer

    Declare Function p9016_axis_set_profile Lib "Pci9016.dll" (ByVal axis As Integer, ByVal min_vel As Double, ByVal max_vel As Double, ByVal accel As Double, ByVal decel As Double, ByVal jerk As Double) As Integer
    Declare Function p9016_axis_set_parameter Lib "Pci9016.dll" (ByVal axis As Integer, ByVal param_num As Integer, ByVal value As Integer) As Integer
    Declare Function p9016_axis_get_status Lib "Pci9016.dll" (ByVal axis As Integer, ByRef pStat As MOT_AXIS_STAT) As Integer

    Declare Function p9016_cmp_enable Lib "Pci9016.dll" (ByVal card_no As Integer, ByVal index As Integer, ByVal enable As Integer, ByVal active_level As Integer, ByVal ref_source As Integer, ByVal length As Integer) As Integer
    Declare Function p9016_cmp_set_ref Lib "Pci9016.dll" (ByVal card_no As Integer, ByVal index As Integer, ByVal pos As Integer) As Integer
    Declare Function p9016_cmp_get_status Lib "Pci9016.dll" (ByVal card_no As Integer, ByVal index As Integer, ByRef pStatus As MOT_CMP_STAT) As Integer

    Declare Function p9016_motion_set_dout Lib "Pci9016.dll" (ByVal card_no As Integer, ByVal index As Integer, ByVal value As Integer) As Integer
    Declare Function p9016_motion_set_dout_ex Lib "Pci9016.dll" (ByVal card_no As Integer, ByVal value As UInteger) As Integer
    Declare Function p9016_motion_get_dout Lib "Pci9016.dll" (ByVal card_no As Integer, ByVal index As Integer, ByRef pValue As Integer) As Integer
    Declare Function p9016_motion_get_dout_ex Lib "Pci9016.dll" (ByVal card_no As Integer, ByRef pValue As UInteger) As Integer
    Declare Function p9016_motion_get_din Lib "Pci9016.dll" (ByVal card_no As Integer, ByVal index As Integer, ByRef value As Integer) As Integer
    Declare Function p9016_motion_get_din_ex Lib "Pci9016.dll" (ByVal card_no As Integer, ByRef value As UInteger) As Integer

    Declare Function p9016_motion_get_info Lib "Pci9016.dll" (ByVal card_no As Integer, ByVal buff As UInteger(), ByVal cnt As Integer) As Integer
#End Region
End Module